@@ -55,7 +55,7 @@ Resolver *dnscache;
  * Version should be set in configure.ac
  *
  */
-char *cvsid = "$Id: main.cc 233 2005-05-11 22:16:02Z matt $";
+char *cvsid = "$Id: main.cc 246 2008-01-19 23:13:17Z matt $";
 char *version = PACKAGE_VERSION;
 
 /* Get this show on the road */
@@ -78,7 +78,10 @@ int main(int argc, char **argv) {
         
 	/* Initialise ip2user mappings */
 	init_ip2user();
-        
+
+	/* Initialise destination site filtering */
+	init_sitefilter();
+
 	if (srg.verbose) {
 		fprintf(stderr, "Configuration Completed.\n");
 		fprintf(stderr, "Beginning Analysation...\n");
@@ -274,7 +277,7 @@ void process_logs(void)
 		srg.endTime = srg.maxTime;
 	assert(srg.startTime > 0);
 	assert(srg.endTime > 0);
-	assert(srg.endTime > srg.startTime);
+	assert(srg.endTime >= srg.startTime);
 
 	if (srg.verbose) {
 		fprintf(stderr, "Analysed Time Range: %d -> %d\n", srg.startTime,
@@ -510,6 +513,13 @@ int process_line(const log_line *line)
 		}
 	}
 
+	/* If site destination filter is in effect check the line */
+	if (srg.sitefilter) {
+		if (destination_is_excluded(line->request->site)) {
+			return 0; // Don't do any further processing
+		}
+	}
+
 	/* Grouping? */
 	if (srg.groupBy <= 0) {
 		/* Process the line */
